var NAVTREEINDEX18 =
{
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[5,0,1,2,1,0,2,2,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla.html":[6,0,0,2,0,0,2,1,3],
"namespaceviennacl_1_1device__specific_1_1builtin__database_1_1devices_1_1gpu_1_1nvidia_1_1tesla_1_1geforce__gtx__260.html":[5,0,1,2,1,0,2,2,3,0],
"namespaceviennacl_1_1device__specific_1_1detail.html":[5,0,1,2,2],
"namespaceviennacl_1_1device__specific_1_1profiles.html":[5,0,1,2,3],
"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[6,0,0,2,1],
"namespaceviennacl_1_1device__specific_1_1tree__parsing.html":[5,0,1,2,4],
"namespaceviennacl_1_1device__specific_1_1utils.html":[5,0,1,2,5],
"namespaceviennacl_1_1device__specific_1_1utils.html":[6,0,0,2,2],
"namespaceviennacl_1_1io.html":[6,0,0,3],
"namespaceviennacl_1_1io.html":[5,0,1,3],
"namespaceviennacl_1_1io_1_1detail.html":[5,0,1,3,0],
"namespaceviennacl_1_1io_1_1tag.html":[5,0,1,3,1],
"namespaceviennacl_1_1io_1_1val.html":[5,0,1,3,2],
"namespaceviennacl_1_1linalg.html":[5,0,1,4],
"namespaceviennacl_1_1linalg.html":[6,0,0,4],
"namespaceviennacl_1_1linalg_1_1cuda.html":[6,0,0,4,0],
"namespaceviennacl_1_1linalg_1_1cuda.html":[5,0,1,4,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[6,0,0,4,0,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail.html":[5,0,1,4,0,0],
"namespaceviennacl_1_1linalg_1_1cuda_1_1detail_1_1fft.html":[5,0,1,4,0,0,0],
"namespaceviennacl_1_1linalg_1_1detail.html":[6,0,0,4,1],
"namespaceviennacl_1_1linalg_1_1detail.html":[5,0,1,4,1],
"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[6,0,0,4,1,0],
"namespaceviennacl_1_1linalg_1_1detail_1_1amg.html":[5,0,1,4,1,0],
"namespaceviennacl_1_1linalg_1_1detail_1_1fft.html":[5,0,1,4,1,1],
"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[5,0,1,4,1,2],
"namespaceviennacl_1_1linalg_1_1detail_1_1spai.html":[6,0,0,4,1,1],
"namespaceviennacl_1_1linalg_1_1host__based.html":[5,0,1,4,2],
"namespaceviennacl_1_1linalg_1_1host__based.html":[6,0,0,4,2],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[5,0,1,4,2,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html":[6,0,0,4,2,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[5,0,1,4,2,0,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft.html":[6,0,0,4,2,0,0],
"namespaceviennacl_1_1linalg_1_1host__based_1_1detail_1_1fft_1_1_f_f_t___d_a_t_a___o_r_d_e_r.html":[5,0,1,4,2,0,0,0],
"namespaceviennacl_1_1linalg_1_1kernels.html":[5,0,1,4,3],
"namespaceviennacl_1_1linalg_1_1opencl.html":[5,0,1,4,4],
"namespaceviennacl_1_1linalg_1_1opencl.html":[6,0,0,4,3],
"namespaceviennacl_1_1linalg_1_1opencl_1_1detail.html":[5,0,1,4,4,0],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[5,0,1,4,4,1],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels.html":[6,0,0,4,3,0],
"namespaceviennacl_1_1linalg_1_1opencl_1_1kernels_1_1detail.html":[5,0,1,4,4,1,0],
"namespaceviennacl_1_1ocl.html":[6,0,0,5],
"namespaceviennacl_1_1ocl.html":[5,0,1,5],
"namespaceviennacl_1_1result__of.html":[6,0,0,6],
"namespaceviennacl_1_1result__of.html":[5,0,1,6],
"namespaceviennacl_1_1scheduler.html":[6,0,0,7],
"namespaceviennacl_1_1scheduler.html":[5,0,1,7],
"namespaceviennacl_1_1scheduler_1_1detail.html":[5,0,1,7,0],
"namespaceviennacl_1_1scheduler_1_1preset.html":[5,0,1,7,1],
"namespaceviennacl_1_1scheduler_1_1result__of.html":[5,0,1,7,2],
"namespaceviennacl_1_1scheduler_1_1result__of.html":[6,0,0,7,0],
"namespaceviennacl_1_1tools.html":[5,0,1,8],
"namespaceviennacl_1_1tools.html":[6,0,0,8],
"namespaceviennacl_1_1tools_1_1detail.html":[5,0,1,8,0],
"namespaceviennacl_1_1tools_1_1detail.html":[6,0,0,8,0],
"namespaceviennacl_1_1traits.html":[5,0,1,9],
"namespaceviennacl_1_1traits.html":[6,0,0,9],
"nmf_8cpp-example.html":[8,21],
"nmf_8hpp.html":[7,0,3,4,26],
"nmf_8hpp.html#a1682d7a829cecf20106e407aed749a49":[7,0,3,4,26,0],
"nmf_8hpp_source.html":[7,0,3,4,26],
"norm__1_8hpp.html":[7,0,3,4,27],
"norm__1_8hpp.html#a18799037aaa2e6b5e1778cdf203a0274":[7,0,3,4,27,1],
"norm__1_8hpp.html#a2efad0d090dde0c127fa8b25a73836e4":[7,0,3,4,27,0],
"norm__1_8hpp.html#ab5b81d05ed5510a3142a5f29e8b2525f":[7,0,3,4,27,2],
"norm__1_8hpp_source.html":[7,0,3,4,27],
"norm__2_8hpp.html":[7,0,3,4,28],
"norm__2_8hpp.html#a2a22bc2566ec601883db764cf08950c9":[7,0,3,4,28,2],
"norm__2_8hpp.html#abdb24aada7fa315529db8931ed08cd5b":[7,0,3,4,28,1],
"norm__2_8hpp.html#ae46f15d01c01f92a153b3f555a15096b":[7,0,3,4,28,0],
"norm__2_8hpp_source.html":[7,0,3,4,28],
"norm__frobenius_8hpp.html":[7,0,3,4,29],
"norm__frobenius_8hpp.html#a67813d48ed274df9fc19e6aad99fc761":[7,0,3,4,29,0],
"norm__frobenius_8hpp_source.html":[7,0,3,4,29],
"norm__inf_8hpp.html":[7,0,3,4,30],
"norm__inf_8hpp.html#a3097c09e7f5ec6aa812420965f147f69":[7,0,3,4,30,1],
"norm__inf_8hpp.html#ae4de9152d556e89d823eb47a683ead11":[7,0,3,4,30,0],
"norm__inf_8hpp.html#af6ac490ffc6af2faebcc33724bba120e":[7,0,3,4,30,2],
"norm__inf_8hpp_source.html":[7,0,3,4,30],
"ocl_2context_8hpp.html":[7,0,3,7,2],
"ocl_2context_8hpp_source.html":[7,0,3,7,2],
"ocl_2forwards_8h.html":[7,0,3,7,7],
"ocl_2forwards_8h.html#a16fc917445ce2010e7b16fbc968771b7":[7,0,3,7,7,6],
"ocl_2forwards_8h.html#a2d90eef0a67b2af2801368b3ab5b357f":[7,0,3,7,7,5],
"ocl_2forwards_8h.html#a5f2022f653ea1cf364d20e3ff84dcada":[7,0,3,7,7,8],
"ocl_2forwards_8h.html#ac54d59a74deaccec81f64e738b856348":[7,0,3,7,7,7],
"ocl_2forwards_8h_source.html":[7,0,3,7,7],
"ocl_2handle_8hpp.html":[7,0,3,7,8],
"ocl_2handle_8hpp_source.html":[7,0,3,7,8],
"ocl_2utils_8hpp.html":[7,0,3,7,13],
"ocl_2utils_8hpp.html#a3d0a622dfc7a23f67a910cdf7ba136d1":[7,0,3,7,13,3],
"ocl_2utils_8hpp.html#ae6cefd8a9e31c46c74dbf0ca3fee99b7":[7,0,3,7,13,2],
"ocl_2utils_8hpp_source.html":[7,0,3,7,13],
"op__applier_8hpp.html":[7,0,3,4,1,4],
"op__applier_8hpp_source.html":[7,0,3,4,1,4],
"op__executor_8hpp.html":[7,0,3,4,1,5],
"op__executor_8hpp.html#a15870cf2408c54a30bfc83ffb20bddd4":[7,0,3,4,1,5,5],
"op__executor_8hpp.html#a1cddb14e85ad0aa42c4ca2735ff19b22":[7,0,3,4,1,5,4],
"op__executor_8hpp.html#a373f367671e805b21842003c0f2558a5":[7,0,3,4,1,5,2],
"op__executor_8hpp.html#a79870ae9630f024470de327e3d59382c":[7,0,3,4,1,5,3],
"op__executor_8hpp.html#ac2f1b86854e69606cf770160035195c9":[7,0,3,4,1,5,6],
"op__executor_8hpp.html#adfc29cc62dad0223eb764418820eb1b5":[7,0,3,4,1,5,1],
"op__executor_8hpp_source.html":[7,0,3,4,1,5],
"opencl_2bisect__kernel__calls_8hpp.html":[7,0,3,4,3,1],
"opencl_2bisect__kernel__calls_8hpp.html#a211407186265df14562ef8a817792fd9":[7,0,3,4,3,1,6],
"opencl_2bisect__kernel__calls_8hpp.html#a54ae8d98050f97cdccbdf861e1bdcaac":[7,0,3,4,3,1,2],
"opencl_2bisect__kernel__calls_8hpp.html#a72d6ad3f4638199544ac423cb50e558b":[7,0,3,4,3,1,4],
"opencl_2bisect__kernel__calls_8hpp.html#a8342e150624fb250ba6fd27594c1528c":[7,0,3,4,3,1,5],
"opencl_2bisect__kernel__calls_8hpp.html#a8d4833409b5c51a51ccf5d7d6d01adab":[7,0,3,4,3,1,1],
"opencl_2bisect__kernel__calls_8hpp.html#ab7abe46ac1edc749432987ddcfd87b49":[7,0,3,4,3,1,0],
"opencl_2bisect__kernel__calls_8hpp.html#abd665da5291cf6cf9f6c4eab058df182":[7,0,3,4,3,1,7],
"opencl_2bisect__kernel__calls_8hpp.html#ae3bd5c49f889451efee98229ca6d14f3":[7,0,3,4,3,1,3],
"opencl_2bisect__kernel__calls_8hpp_source.html":[7,0,3,4,3,1],
"opencl_2direct__solve_8hpp.html":[7,0,3,4,3,3],
"opencl_2direct__solve_8hpp.html#a3b425cc7c38c19cc16f34eb0c349a3e2":[7,0,3,4,3,3,3],
"opencl_2direct__solve_8hpp.html#a64f1e9f297e72762dd45b29214ae71fd":[7,0,3,4,3,3,0],
"opencl_2direct__solve_8hpp.html#a78416d62615725d511d7cdbd74e3235b":[7,0,3,4,3,3,2],
"opencl_2direct__solve_8hpp.html#a9d003d00f2cab87b7bc7ebdd472bf1f2":[7,0,3,4,3,3,1],
"opencl_2direct__solve_8hpp.html#ac213c5f1e1f1b9d18e7b94acb9e17279":[7,0,3,4,3,3,6],
"opencl_2direct__solve_8hpp.html#ac90a3dca0595b15ae04662bddb6cf57c":[7,0,3,4,3,3,4],
"opencl_2direct__solve_8hpp.html#ad6cf7d9d8b5ccaf3088350c4b9168dc5":[7,0,3,4,3,3,5],
"opencl_2direct__solve_8hpp_source.html":[7,0,3,4,3,3],
"opencl_2fft__operations_8hpp.html":[7,0,3,4,3,4],
"opencl_2fft__operations_8hpp.html#a0471ee9c12af0be8cd6c3e231099da17":[7,0,3,4,3,4,10],
"opencl_2fft__operations_8hpp.html#a1b006c21985b1c6454cec4a7ad66a381":[7,0,3,4,3,4,7],
"opencl_2fft__operations_8hpp.html#a1d99dc6015c8864a1b6ed28f813213f5":[7,0,3,4,3,4,8],
"opencl_2fft__operations_8hpp.html#a26cc8c388060b9785276efa43df28350":[7,0,3,4,3,4,4],
"opencl_2fft__operations_8hpp.html#a4175ed00a2602908a1e26d735c3349aa":[7,0,3,4,3,4,11],
"opencl_2fft__operations_8hpp.html#a4b510a646bf1fa6cf85b8df1d37e696f":[7,0,3,4,3,4,6],
"opencl_2fft__operations_8hpp.html#a4e9922fb38a92859cebcb2d4366cac40":[7,0,3,4,3,4,13],
"opencl_2fft__operations_8hpp.html#a6c0011a9f0af1adbb45b9967fabfdea6":[7,0,3,4,3,4,12],
"opencl_2fft__operations_8hpp.html#a7a3b6214329a69e393456e5476643da4":[7,0,3,4,3,4,3],
"opencl_2fft__operations_8hpp.html#a8c3ec6e5ff9ab79321aa9a172bc01217":[7,0,3,4,3,4,5],
"opencl_2fft__operations_8hpp.html#a8c68275a2d4ecac596bc102a4ecde7af":[7,0,3,4,3,4,0],
"opencl_2fft__operations_8hpp.html#aa793781a3fde5be3d2c608f3802538e0":[7,0,3,4,3,4,2],
"opencl_2fft__operations_8hpp.html#ae3d993c18bd47b02a185299a606d6b6a":[7,0,3,4,3,4,1],
"opencl_2fft__operations_8hpp.html#af6f07b4ef9acd085eeccf36d5d5f0868":[7,0,3,4,3,4,9],
"opencl_2fft__operations_8hpp_source.html":[7,0,3,4,3,4],
"opencl_2iterative__operations_8hpp.html":[7,0,3,4,3,5],
"opencl_2iterative__operations_8hpp.html#a042962f819feb720caace79aa6dc204c":[7,0,3,4,3,5,7],
"opencl_2iterative__operations_8hpp.html#a09d065cb8352a3b50fea0e2a8f4fc542":[7,0,3,4,3,5,8],
"opencl_2iterative__operations_8hpp.html#a0e7a262c0237222d9f9dc38b66a2a241":[7,0,3,4,3,5,12],
"opencl_2iterative__operations_8hpp.html#a39cd29b90bcdc32c34a53887787b0108":[7,0,3,4,3,5,6],
"opencl_2iterative__operations_8hpp.html#a500bc82556ca654ed2fcf54d2880e58a":[7,0,3,4,3,5,14],
"opencl_2iterative__operations_8hpp.html#a578ba28f1fd57934764628b14d5135ae":[7,0,3,4,3,5,20],
"opencl_2iterative__operations_8hpp.html#a7f61155d92b8a7ee4f88f0492d057d7f":[7,0,3,4,3,5,3],
"opencl_2iterative__operations_8hpp.html#a90b7869524040319393eccfc821918aa":[7,0,3,4,3,5,15],
"opencl_2iterative__operations_8hpp.html#a9415aa45a78c82eae3927ac06d88128a":[7,0,3,4,3,5,16],
"opencl_2iterative__operations_8hpp.html#a99d7431780543d40b2fc7a260f6a1d31":[7,0,3,4,3,5,13],
"opencl_2iterative__operations_8hpp.html#a9e6b2439253b8f03fb5d47da101d0ff4":[7,0,3,4,3,5,19],
"opencl_2iterative__operations_8hpp.html#ab8a2fa51a5ff6afc3bb42679053de2ca":[7,0,3,4,3,5,10],
"opencl_2iterative__operations_8hpp.html#ac781100abed5c80cd0963b56b5a23802":[7,0,3,4,3,5,1],
"opencl_2iterative__operations_8hpp.html#ad3b70ebae2895a35920471bc49908af7":[7,0,3,4,3,5,4],
"opencl_2iterative__operations_8hpp.html#ad941d6a75fcdcd7691be5b41a73eaa15":[7,0,3,4,3,5,0],
"opencl_2iterative__operations_8hpp.html#adc5a991a51dc7fef188f159e4e0b9843":[7,0,3,4,3,5,9],
"opencl_2iterative__operations_8hpp.html#ae3d1d31061c1a07b6eb46d1edf92408b":[7,0,3,4,3,5,2],
"opencl_2iterative__operations_8hpp.html#ae6c44ba1bb74bdab61b795245b494729":[7,0,3,4,3,5,21],
"opencl_2iterative__operations_8hpp.html#af5b89eb71abc46bd4b311824510b0c0e":[7,0,3,4,3,5,5],
"opencl_2iterative__operations_8hpp.html#afa2f92faa72df7fe9bc7cc86b99e04f8":[7,0,3,4,3,5,18],
"opencl_2iterative__operations_8hpp.html#afe888929fb5aa4f38f87b722159f7197":[7,0,3,4,3,5,11],
"opencl_2iterative__operations_8hpp.html#aff9245a27665aa7424561cf0774d7618":[7,0,3,4,3,5,17],
"opencl_2iterative__operations_8hpp_source.html":[7,0,3,4,3,5],
"opencl_2kernels_2bisect_8hpp.html":[7,0,3,4,3,0,0],
"opencl_2kernels_2bisect_8hpp.html#a09ed7eec8dad46f4195810d9aafa61b9":[7,0,3,4,3,0,0,13],
"opencl_2kernels_2bisect_8hpp.html#a0eb281943b230be124abecce8a3fea6b":[7,0,3,4,3,0,0,16],
"opencl_2kernels_2bisect_8hpp.html#a1366d88e3dc6ca1789d45ad963fdaeb8":[7,0,3,4,3,0,0,14],
"opencl_2kernels_2bisect_8hpp.html#a1caa05ae768ebecd644418202f23cb3b":[7,0,3,4,3,0,0,24],
"opencl_2kernels_2bisect_8hpp.html#a2a4b8d5d1e1da364345b4846035dde7c":[7,0,3,4,3,0,0,7],
"opencl_2kernels_2bisect_8hpp.html#a2a616e5afb93ae1f2c59fcb93aa99a53":[7,0,3,4,3,0,0,3],
"opencl_2kernels_2bisect_8hpp.html#a364186fe09148b1b12c83a472f19d745":[7,0,3,4,3,0,0,26],
"opencl_2kernels_2bisect_8hpp.html#a3b5db806d7e384d6384205815cb49f6e":[7,0,3,4,3,0,0,6],
"opencl_2kernels_2bisect_8hpp.html#a3bf5e9e8c82f0301f0866dce841a8118":[7,0,3,4,3,0,0,20],
"opencl_2kernels_2bisect_8hpp.html#a48bea4f56f9bc4d20db56ab72fb31238":[7,0,3,4,3,0,0,4],
"opencl_2kernels_2bisect_8hpp.html#a4b1c1b444ac75cf63c74841f757f3be1":[7,0,3,4,3,0,0,2],
"opencl_2kernels_2bisect_8hpp.html#a54eb8a1e8a9e0077bd6b5108a62c5d19":[7,0,3,4,3,0,0,8],
"opencl_2kernels_2bisect_8hpp.html#a567689e2cd00785a357a79c9f38eab65":[7,0,3,4,3,0,0,19],
"opencl_2kernels_2bisect_8hpp.html#a5dda99b34ad4350282b37e516ad43d90":[7,0,3,4,3,0,0,12],
"opencl_2kernels_2bisect_8hpp.html#a71b55d82d86e52a36f7a980e1e1cb60f":[7,0,3,4,3,0,0,9],
"opencl_2kernels_2bisect_8hpp.html#a7b378daca265ef32c0cab788bc5d6fda":[7,0,3,4,3,0,0,15],
"opencl_2kernels_2bisect_8hpp.html#a930bf5582d6407ead9532a49a51714be":[7,0,3,4,3,0,0,5],
"opencl_2kernels_2bisect_8hpp.html#a983cf94c8567dab6900a9d5f936bcb2f":[7,0,3,4,3,0,0,1],
"opencl_2kernels_2bisect_8hpp.html#aad695fe296aa9e3b6a0dc4c472ad0cd3":[7,0,3,4,3,0,0,23],
"opencl_2kernels_2bisect_8hpp.html#aaf9b91abeeeaf47b193c4a8a3d92af79":[7,0,3,4,3,0,0,27],
"opencl_2kernels_2bisect_8hpp.html#abb35aa119edd08603fb58bf34d249167":[7,0,3,4,3,0,0,17],
"opencl_2kernels_2bisect_8hpp.html#abc6b25fb3693f18d024c5a1615852428":[7,0,3,4,3,0,0,21],
"opencl_2kernels_2bisect_8hpp.html#ac18d6335f8af7eb8ef3053acbf1f9ce5":[7,0,3,4,3,0,0,18],
"opencl_2kernels_2bisect_8hpp.html#acd7b8f4a45a0a33a994c89589efd9cf0":[7,0,3,4,3,0,0,10],
"opencl_2kernels_2bisect_8hpp.html#ae8638f026e01f96697536552db93212f":[7,0,3,4,3,0,0,11],
"opencl_2kernels_2bisect_8hpp.html#af691d922a1d82dbc23382b2b3042366b":[7,0,3,4,3,0,0,25],
"opencl_2kernels_2bisect_8hpp.html#aff62149c62908e2fa37bfbf85a4a5cdf":[7,0,3,4,3,0,0,22],
"opencl_2kernels_2bisect_8hpp_source.html":[7,0,3,4,3,0,0],
"opencl_2kernels_2ilu_8hpp.html":[7,0,3,4,3,0,7],
"opencl_2kernels_2ilu_8hpp.html#a250af558e33347dfe02d1396a046e527":[7,0,3,4,3,0,7,1],
"opencl_2kernels_2ilu_8hpp_source.html":[7,0,3,4,3,0,7],
"opencl_2kernels_2nmf_8hpp.html":[7,0,3,4,3,0,11],
"opencl_2kernels_2nmf_8hpp.html#a2a18b14d636474012cbb5cd6c160c282":[7,0,3,4,3,0,11,1],
"opencl_2kernels_2nmf_8hpp_source.html":[7,0,3,4,3,0,11],
"opencl_2kernels_2spai_8hpp.html":[7,0,3,4,3,0,14],
"opencl_2kernels_2spai_8hpp.html#a0ef446958eadb7566af5af164c42d753":[7,0,3,4,3,0,14,6],
"opencl_2kernels_2spai_8hpp.html#a46c06e71a895b596b14c63ebc30d6da0":[7,0,3,4,3,0,14,5],
"opencl_2kernels_2spai_8hpp.html#a59c4e99f39339ce7adfbb4793ec9a90f":[7,0,3,4,3,0,14,4],
"opencl_2kernels_2spai_8hpp.html#a684d46d7a6d25da9315a650389a6b9a6":[7,0,3,4,3,0,14,8],
"opencl_2kernels_2spai_8hpp.html#a6fc75b18244da56426784cbf789c030c":[7,0,3,4,3,0,14,1],
"opencl_2kernels_2spai_8hpp.html#a8aa3b4bed4795a77017bf4419fd3b180":[7,0,3,4,3,0,14,3],
"opencl_2kernels_2spai_8hpp.html#a947e6322493e8087cfd86d03fd858189":[7,0,3,4,3,0,14,2],
"opencl_2kernels_2spai_8hpp.html#af432061aaf6283a75ec3b81ac0ab0f48":[7,0,3,4,3,0,14,7],
"opencl_2kernels_2spai_8hpp_source.html":[7,0,3,4,3,0,14],
"opencl_2kernels_2svd_8hpp.html":[7,0,3,4,3,0,15],
"opencl_2kernels_2svd_8hpp.html#a05c094cce4f664453c155eafaa0646f7":[7,0,3,4,3,0,15,16],
"opencl_2kernels_2svd_8hpp.html#a198d151faa9ed845841dd6e54c4d1720":[7,0,3,4,3,0,15,2],
"opencl_2kernels_2svd_8hpp.html#a2314bf6a3ca995899978c2504eacdb4b":[7,0,3,4,3,0,15,9],
"opencl_2kernels_2svd_8hpp.html#a2b6175d3f83cd821e06daab3ac1ad466":[7,0,3,4,3,0,15,1],
"opencl_2kernels_2svd_8hpp.html#a3d491ad5e547bb8ba50b134cf473e200":[7,0,3,4,3,0,15,5],
"opencl_2kernels_2svd_8hpp.html#a3e7ada351d176c2c90a63032f3eabdcf":[7,0,3,4,3,0,15,7],
"opencl_2kernels_2svd_8hpp.html#a4e33eaa3133dcc8c050b877e628b531a":[7,0,3,4,3,0,15,15],
"opencl_2kernels_2svd_8hpp.html#a71cf92278b63ea07b23d70621e64221e":[7,0,3,4,3,0,15,3],
"opencl_2kernels_2svd_8hpp.html#a78798a502627ec375d52f3857d556965":[7,0,3,4,3,0,15,13],
"opencl_2kernels_2svd_8hpp.html#a8506b81f8f6e700161e4a67d4f2c8dc2":[7,0,3,4,3,0,15,11],
"opencl_2kernels_2svd_8hpp.html#a94f9fe10c3a77798a44a0dcce9480e1b":[7,0,3,4,3,0,15,19],
"opencl_2kernels_2svd_8hpp.html#a986156e7f4ee31480fbe542ec4890c46":[7,0,3,4,3,0,15,10],
"opencl_2kernels_2svd_8hpp.html#aa02c92f95d3fa5183013ce74756249cd":[7,0,3,4,3,0,15,6],
"opencl_2kernels_2svd_8hpp.html#aa6d359797763e880a73bd22c1f87fc10":[7,0,3,4,3,0,15,12],
"opencl_2kernels_2svd_8hpp.html#abb44553f086222188bf3d0413bcc634c":[7,0,3,4,3,0,15,18],
"opencl_2kernels_2svd_8hpp.html#ac6a619337d349abc2e69236f4bba7416":[7,0,3,4,3,0,15,4],
"opencl_2kernels_2svd_8hpp.html#acd1b7bfd307875135e20920575174e4e":[7,0,3,4,3,0,15,14],
"opencl_2kernels_2svd_8hpp.html#afb2fe1df86a78f4f2f97742f6b463b29":[7,0,3,4,3,0,15,8],
"opencl_2kernels_2svd_8hpp.html#afd31722ab4974d2797181d4619842921":[7,0,3,4,3,0,15,17],
"opencl_2kernels_2svd_8hpp_source.html":[7,0,3,4,3,0,15],
"opencl_2matrix__operations_8hpp.html":[7,0,3,4,3,6],
"opencl_2matrix__operations_8hpp.html#a0c1e78c33de1edf10a666c2a3d561af3":[7,0,3,4,3,6,33],
"opencl_2matrix__operations_8hpp.html#a16366a34aab924b279bcd2b4f403a159":[7,0,3,4,3,6,22],
"opencl_2matrix__operations_8hpp.html#a23eccb767cb852d60170403a671dd91b":[7,0,3,4,3,6,15],
"opencl_2matrix__operations_8hpp.html#a24049445243113b8aff433e4dd6d3c01":[7,0,3,4,3,6,31],
"opencl_2matrix__operations_8hpp.html#a24d101c5571414986506c8170ce4f261":[7,0,3,4,3,6,36],
"opencl_2matrix__operations_8hpp.html#a37fbfb949aae5a860d0308717e5b4ff5":[7,0,3,4,3,6,4],
"opencl_2matrix__operations_8hpp.html#a42d8cc5fddc8d8fe7819428f3570d8d7":[7,0,3,4,3,6,11],
"opencl_2matrix__operations_8hpp.html#a5077728cfc9a2f2bdf1e480948a3fe6f":[7,0,3,4,3,6,34],
"opencl_2matrix__operations_8hpp.html#a55efe16c86efff4d42bfa7ecea29fa70":[7,0,3,4,3,6,28],
"opencl_2matrix__operations_8hpp.html#a5d5b4fe8827c4d4da9f2df19cf8ee971":[7,0,3,4,3,6,6],
"opencl_2matrix__operations_8hpp.html#a656519064a982e5904b5a66b5e9c2785":[7,0,3,4,3,6,32],
"opencl_2matrix__operations_8hpp.html#a66235632539f84b9a5da2df6da5b573d":[7,0,3,4,3,6,9],
"opencl_2matrix__operations_8hpp.html#a6860ecc724d3ef7a1ba363c379357abf":[7,0,3,4,3,6,16],
"opencl_2matrix__operations_8hpp.html#a6c692160febc1bf0c8c1b3f14609843b":[7,0,3,4,3,6,25],
"opencl_2matrix__operations_8hpp.html#a72bf0d80c0608b5645d06703c7807253":[7,0,3,4,3,6,24],
"opencl_2matrix__operations_8hpp.html#a786d68766ad5e6b6fb239274efde0bf7":[7,0,3,4,3,6,13],
"opencl_2matrix__operations_8hpp.html#a7e146ec12db4a4ec440d6ca9b8e46b79":[7,0,3,4,3,6,2],
"opencl_2matrix__operations_8hpp.html#a83f95bb0dba31593bfdea7d48825ef45":[7,0,3,4,3,6,26],
"opencl_2matrix__operations_8hpp.html#a86b4bd11f0b1f0b701afa9448cbb865f":[7,0,3,4,3,6,30],
"opencl_2matrix__operations_8hpp.html#a896e84eed510eabefb25c2dc08bffef4":[7,0,3,4,3,6,0]
};
